@@ -17,21 +17,6 @@ import datetime
 import re
 
 
-def visit_html_recentpages(self, node):
-    env = self.builder.env
-    file_list = get_file_list_ordered_by_mtime(env)
-
-    num = node['num']
-    n = len(file_list) if num < 0 else num
-
-    self.body += _generate_html(file_list, n)
-    raise nodes.SkipNode
-
-
-def depart_recentpages(self, node):
-    pass
-
-
 def setup(app):
     app.add_node(recentpages,
                  html=(visit_html_recentpages, depart_recentpages))
@@ -65,16 +50,108 @@ class RecentpagesDirective(Directive):
         env = self.state.document.settings.env
         env.note_reread()
 
+        # generate pagename
+        # docpath: full path of the document
+        # srcdir: document root directory
+        docpath = self.state.document.current_source
+        srcdir = env.srcdir
+        pagename = docpath.replace(srcdir, '').lstrip('/').rpartition('.')[0]
+
         num = self.options.get('num', -1)
         res = recentpages('')
+
+        res['pagename'] = pagename
         res['num'] = num
+
         return [res]
 
 
+def visit_html_recentpages(self, node):
+    """visitor method for recentpages node
+    """
+
+    builder = self.builder
+    env = self.builder.env
+    file_list = _get_file_list_ordered_by_mtime(env)
+
+    n = node['num']
+    num = len(file_list) if n < 0 else n
+
+    # generate directive html contents
+
+    html_content = []
+
+    for docname, mtime, title in file_list:
+        pagename = node['pagename']
+        relative_uri = builder.get_relative_uri(pagename, docname)
+
+        # append a doc information
+        html_content.append('%s - ' % datetime.datetime.fromtimestamp(mtime))
+        html_content.append('<a href="%s">' % relative_uri)
+        html_content.append('%s</a><br />' % title)
+
+        # append only most recent 'num' docs
+        num -= 1
+        if num <= 0:
+            break
+
+    self.body += html_content
+
+    raise nodes.SkipNode
+
+
+def depart_recentpages(self, node):
+    pass
+
+
+def generate_recentpages_html(app, pagename, templatename, context, doctree):
+    """generate recentpage sidebar parts.
+    """
+
+    if not app.builder.config.recentpages_sidebar:
+        return
+
+    context['recentpages_sidebar'] = True
+
+    builder = app.builder
+    env = app.builder.env
+    num = app.builder.config.recentpages_sidebar_pages
+
+    file_list = _get_file_list_ordered_by_mtime(env)
+
+    # generate sidebar html contents
+
+    html_content = []
+
+    current_mday = ""
+
+    for docname, mtime, title in file_list:
+        relative_uri = builder.get_relative_uri(pagename, docname)
+
+        # group all docs which was modified on the same day
+        mday = datetime.datetime.fromtimestamp(mtime).strftime("%Y-%m-%d")
+        if current_mday != mday:
+            current_mday = mday
+            html_content.append('<b>%s</b><br />' % current_mday)
+
+        # append a doc information
+        html_content.append('<div style="margin-left:16px">')
+        html_content.append('<a href="%s">' % relative_uri)
+        html_content.append('%s</a><br />' % title)
+        html_content.append('</div>')
+
+        # append only most recent 'recentpages_sidebar_pages' docs
+        num -= 1
+        if num <= 0:
+            break
+
+    context['recentpages_content'] = ''.join(html_content)
+
+
 explicit_title_re = re.compile(r'^<(.*?)>(.+?)\s*(?<!\x00)<(.*?)>$', re.DOTALL)
 
 
-def get_file_list_ordered_by_mtime(env):
+def _get_file_list_ordered_by_mtime(env):
     res = []
 
     for docname in env.found_docs:
@@ -95,6 +172,10 @@ def get_file_list_ordered_by_mtime(env):
 
 
 def generate_template(app, env):
+    """Generate recentpages.html template on update.
+    This template is used in sidebar.
+    """
+
     if not app.builder.config.recentpages_sidebar:
         return
 
@@ -120,6 +201,8 @@ def generate_template(app, env):
         app.builder.warn("%s is not writable" % (template_dir,))
         return
 
+    # main routime. create template file to template directory.
+
     contents = """{#
     recentpages.html
     ~~~~~~~~~~~~~~~~
@@ -140,51 +223,3 @@ def generate_template(app, env):
         op.write(contents)
     finally:
         op.close()
-
-
-def generate_recentpages_html(app, pagename, templatename, context, doctree):
-    if not app.builder.config.recentpages_sidebar:
-        return
-
-    context['recentpages_sidebar'] = True
-    NUM_OF_PAGES = app.builder.config.recentpages_sidebar_pages
-
-    env = app.builder.env
-    file_list = get_file_list_ordered_by_mtime(env)
-    html_content = _generate_html_sidebar(file_list, NUM_OF_PAGES)
-
-    context['recentpages_content'] = ''.join(html_content)
-
-
-def _generate_html(file_list, num):
-    html_content = []
-    for docname, mtime, title in file_list:
-        html_content.append('%s - ' % datetime.datetime.fromtimestamp(mtime))
-        html_content.append('<a href="%s.html">' % docname)
-        html_content.append('%s</a><br />' % title)
-        num -= 1
-        if num <= 0:
-            break
-
-    return html_content
-
-
-def _generate_html_sidebar(file_list, num):
-    html_content = []
-
-    current_mday = ""
-
-    for docname, mtime, title in file_list:
-        mday = datetime.datetime.fromtimestamp(mtime).strftime("%Y-%m-%d")
-        if current_mday != mday:
-            current_mday = mday
-            html_content.append('<b>%s</b><br />' % current_mday)
-        html_content.append('<div style="margin-left:16px">')
-        html_content.append('<a href="%s.html">' % docname)
-        html_content.append('%s</a><br />' % title)
-        html_content.append('</div>')
-        num -= 1
-        if num <= 0:
-            break
-
-    return html_content
